summaryrefslogtreecommitdiffstats
path: root/content/browser/geolocation/network_location_provider.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/browser/geolocation/network_location_provider.h')
-rw-r--r--content/browser/geolocation/network_location_provider.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/content/browser/geolocation/network_location_provider.h b/content/browser/geolocation/network_location_provider.h
index 710fd3f..daf0c8b 100644
--- a/content/browser/geolocation/network_location_provider.h
+++ b/content/browser/geolocation/network_location_provider.h
@@ -82,18 +82,18 @@ class NetworkLocationProvider
// Satisfies a position request from cache or network.
void RequestPosition();
- // Called from a callback when new wifi data is available.
- void WifiDataUpdateAvailable(WifiDataProvider* provider);
+ // Gets called when new wifi data is available.
+ void OnWifiDataUpdate(WifiDataProvider* provider);
- // Internal helper used by WifiDataUpdateAvailable.
+ // Internal helper used by OnWifiDataUpdate.
void OnWifiDataUpdated();
bool IsStarted() const;
- void LocationResponseAvailable(const Geoposition& position,
- bool server_error,
- const base::string16& access_token,
- const WifiData& wifi_data);
+ void OnLocationResponse(const Geoposition& position,
+ bool server_error,
+ const base::string16& access_token,
+ const WifiData& wifi_data);
scoped_refptr<AccessTokenStore> access_token_store_;